#
# spec file for package f2fs-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           f2fs-tools
Version:        1.15.0
Release:        2.4
Summary:        Utilities for the Flash-friendly Filesystem (F2FS)
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          System/Filesystems
URL:            https://git.kernel.org/cgit/linux/kernel/git/jaegeuk/f2fs-tools.git
Source:         https://git.kernel.org/pub/scm/linux/kernel/git/jaegeuk/f2fs-tools.git/snapshot/f2fs-tools-%version.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(uuid)
Supplements:    filesystem(f2fs)

%description
Utilities needed to create and maintain so-called Flash-Friendly (F2)
filesystems.

%package -n libf2fs9
Summary:        Library to manipulate F2 filesystems
Group:          System/Libraries

%description -n libf2fs9
This package contains a shared library used for manipulation of F2
filesystems.

%package -n libf2fs_format8
Summary:        Library to create F2 filesystems
Group:          System/Libraries

%description -n libf2fs_format8
This package contains a shared library to format F2 filesystems.

%if 0%{?suse_version} < 1550
%package compat
Summary:        f2fs utility compatibility symlinks
Group:          System/Filesystems
BuildArch:      noarch

%description compat
This subpackage contains symbolic links /sbin/fsck.* and /sbin/mkfs.*
needed for programs that assume these locations.
%endif

%package devel
Summary:        Development files for f2fs
Group:          Development/Languages/C and C++
Requires:       libf2fs9 = %version-%release
Requires:       libf2fs_format8 = %version-%release

%description devel
This package contains development files for %name.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --disable-static
%make_build

%install -p /bin/bash
%make_install
find %buildroot -type f -name "*.la" -delete -print
# sg3_utils already ships this
rm -f "%buildroot/%_sbindir/sg_write_buffer"

mkdir -p "%buildroot/sbin" "%buildroot/%_includedir"
%if 0%{?suse_version} < 1550
ln -sf "%_sbindir"/{defrag.f2fs,dump.f2fs,f2fstat,fibmap.f2fs,fsck.f2fs,mkfs.f2fs,parse.f2fs,resize.f2fs,sload.f2fs} "%buildroot/sbin/"
%endif
# for android-tools… this is of course totally untested.
# The shared library for example has a "main" symbol :-/
cp -a include/f2fs_fs.h mkfs/f2fs_format_utils.h \
	"%buildroot/%_includedir/"

%post   -n libf2fs9 -p /sbin/ldconfig
%postun -n libf2fs9 -p /sbin/ldconfig
%post   -n libf2fs_format8 -p /sbin/ldconfig
%postun -n libf2fs_format8 -p /sbin/ldconfig

%files
%license COPYING
%_sbindir/*
%_mandir/man8/*

%files -n libf2fs9
%_libdir/libf2fs.so.*

%files -n libf2fs_format8
%_libdir/libf2fs_format.so.*

%if 0%{?suse_version} < 1550
%files compat
/sbin/*
%endif

%files devel
%_includedir/*.h
%_libdir/libf2fs*.so

%changelog
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Sun May 29 2022 Dirk Müller <dmueller@suse.com>
- update to 1.15.0:
  * fsck.f2fs: fix broken file_map output
  * f2fs-tools: show segment/section layout correctly
  * dump.f2fs: compress: fix dstlen of LZ4_compress_fast_extState()
  * big endian fixes
  * cross compile fixes
  * mkfs.f2fs: set required quota types only
  * fsck.f2fs: Add progression feedback
  * fsck.f2fs: do not assert if i_size is missing i_blocks in symlink
  * f2fs-tools: separate other bugs in fsck_verify
  * fsck|dump.f2fs: add -M to get file map
- drop f2fs-tools-1.4.0-bigendian.patch: obsolete
* Fri Oct  1 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 1.14.0+g67 (972d7107)
  [boo#1191235]
* Mon May  3 2021 Jan Engelhardt <jengelh@inai.de>
- Remove /usr/sbin/sg_write_buffer. This file is already provided
  by sg3_utils as /usr/bin/sg_write_buffer.
* Tue Nov 24 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Wed Aug 26 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.14
  * f2fs_io: add copy command
  * fsck: Check fsync data always for zoned block devices
  * fsck: Check write pointer consistency of open zones
  * fsck: Check write pointer consistency of non-open zones
  * fsck.f2fs: Enable user-space cache
  * f2fs-tools: support data compression
  * dump.f2fs: print more info of inode layout
  * resize.f2fs: add option for large_nat_bitmap feature
  * f2fs-tools: Casefolded Encryption support
  * mkfs.f2fs: allow setting volume UUID manually
  * f2fs-tools: zns zone-capacity support
  * mkfs.f2fs: add -T flag
  * mkfs.f2fs: add -r (fake_seed) flag
* Mon Dec 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.13
  * introduce some preen mode in fsck.f2fs
  * add f2fs_io tool
  * add casefolding support
* Mon Nov 19 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.12
  * resize.f2fs: fix access out-of memory boundary
  * mkfs.f2fs: support fsverity feature
  * fsck.f2fs: fix stack overflow when reading out nat block
  * mkfs.f2fs: avoid selinux denial for unnecessary sysfs node
  * fsck.f2fs: allow -p without value
  * mkfs.f2fs: support multiple features with one "-O"
  * f2fs-tools: add -g to give default options
* Mon Mar 19 2018 jengelh@inai.de
- Update to version 1.10.0
  * f2fs-tools: support inode creation time
  * fsck.f2fs: add -y for generic fsck
  * fsck.f2fs: support quota
  * mkfs.f2fs: support quota option in mkfs
  * f2fs-tools: support flexible inline xattr size
  * add sparse support for f2fs
  * f2fscrypt: add a tool for encryption management in f2fs
* Sun Aug 28 2016 jengelh@inai.de
- Trim filelists, update descriptions, move symlink collection into
  their own subpackage.
* Sun Aug 28 2016 mpluskal@suse.com
- Update to version 1.7:
  * mkfs: define DISCARD/SECDISCARD macro
  * dump.f2fs: show inode->i_dir_level
  * f2fs.fsck: fix endianess
  * fsck.f2fs: correct variable type and name
  * fsck.f2fs: fix typo
  * fsck.f2fs: free nat entry cache
  * f2fs-tools: update the format of output message
  * fsck.f2fs: clean up duplicated code
  * fsck: recover symlink with zero i_size
  * f2fs-tools: release 1.7.0
- Add f2fs-tools-1.4.0-bigendian.patch (from Fedora)
- Use _service to fetch release from upstream git
- Split lib packages and create devel package (as andoid tools
  need it)
- Link binaries from /usr/sbin to /sbin, many tools expect fsck
  and friends to be in /sbin
- Supplement f2fs filesystem
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream release 1.6.0
  * Add a defrag utility
* Sat Mar 28 2015 jengelh@inai.de
- Update to new upstream release 1.4.1
  * fsck: remove corrupted data indices in direct node blocks
  * fsck/mkfs: support large sector size
  * parse.f2fs: add a tool to parse IO traces made by runtime f2fs
  * fsck: show orphan inodes when fixing partition
- Drop 0001-build-provide-definitions-for-byteswapping-on-big-en.patch
  (merged)
* Tue Sep 23 2014 jengelh@inai.de
- Replace 0001-build-provide-definitions-for-byteswapping-on-big-en.patch
  with official upstream version.
* Fri Sep 19 2014 jengelh@inai.de
- Update to new upstream release 1.4.0
  * fsck: add the -a option (auto-fix errors) [bnc#856645]
  * fsck: remove corrupted xattr blocks and corrupted orphan inodes;
  remove dentry if inode block is corrupted
- Add 0001-build-provide-definitions-for-byteswapping-on-big-en.patch
* Fri Jul 18 2014 jengelh@inai.de
- Update to new snapshot 1.3.0.g22
  * add "f2fstat" program to print f2fs's status in sec
  * mkfs: support large directories
  * mkfs.f2fs, fsck.f2fs: large volume support
* Sun Nov 24 2013 jengelh@inai.de
- Update to new upstream release 1.2.0
  * f2fs-tools: add stat information into fibmap
  * fibmap.f2fs: change fibmap to fibmap.f2fs
  * fsck, lib: support inline xattr
  * fsck: skip to check block addresses in device files
  * fsck: fix to handle file types correctly
  * fsck: fix checking orphan inodes
* Wed Aug  7 2013 jengelh@inai.de
- Update to new snapshot v1.1.0-40-g6e8f2d5
  * Correct endianess conversions for CRC calculations, checkpoint
  flags and in f2fs_update_nat_root.
  * Fix the total_zones calculation in f2fs_prepare_super_block
  * Add the fsck.f2fs and dump.f2fs utilities
* Mon Jun 10 2013 jengelh@inai.de
- Update to new snapshot v1.1.0-24-gfef98eb
  * mkfs: add option to disable trim at format
  * mkfs: handle labels longer than 16 characters
* Mon Jan 21 2013 jengelh@inai.de
- Add COPYING file to package
* Wed Dec 12 2012 jengelh@inai.de
- Initial package (version v1.1.0-11-gc7e0a01) for build.opensuse.org
